Learn R Programming

HiGarrote (version 2.0.0)

blood_glucose: Blood Glucose Experiment

Description

Hamada and Wu (1992) analyzed an 18-run experiment designed to study blood glucose readings of a clinical testing device. The experiment contains one two-level factor and seven three-level quantitative factors, which are denoted by A through H.

Usage

data(blood_glucose)

Arguments

Format

A data frame with 18 rows and 9 columns.